@@ -169,4 +169,9 @@ def autogenerate_validation_steps(
         "validation_steps",
         client=client,
     )
+    if not asset:
+        raise NpValidatorError(
+            "No validation steps associated with project=%s." % project_name
+        )
+
     return [load_ValidationStep(step_data) for step_data in asset]
